This is an automated email from the ASF dual-hosted git repository.

dlmarion pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/accumulo.git

commit 844d79171173a045d94dd1a57d5fd93c99189b81
Merge: 77ae357cf7 66522ba1d1
Author: Dave Marion <dlmar...@apache.org>
AuthorDate: Fri Jun 28 12:01:42 2024 +0000

    Merge branch '2.1'

 .../apache/accumulo/manager/tableOps/Utils.java    | 39 ++++++++++++++++++++--
 .../org/apache/accumulo/test/CreateTableIT.java    |  6 ++--
 2 files changed, 39 insertions(+), 6 deletions(-)

diff --cc test/src/main/java/org/apache/accumulo/test/CreateTableIT.java
index b2166929a1,52346a38d1..d37eeaba3a
--- a/test/src/main/java/org/apache/accumulo/test/CreateTableIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/CreateTableIT.java
@@@ -59,10 -58,9 +59,10 @@@ public class CreateTableIT extends Shar
          client.tableOperations().create(tableNames[i]);
          System.out.println("Table creation took: " + 
(System.currentTimeMillis() - start) + "ms");
        }
        // Confirm all 1000 user tables exist in addition to Root, Metadata,
        // and ScanRef tables
-       assertEquals(1000 + AccumuloTable.allTableIds().size(),
 -      assertEquals(503, client.tableOperations().list().size());
++      assertEquals(500 + AccumuloTable.allTableIds().size(),
 +          client.tableOperations().list().size());
      }
    }
@@@ -59,10 -58,9 +59,10 @@@ public class CreateTableIT extends Shar
(System.currentTimeMillis() - start) + "ms");
        }
-       // Confirm all 1000 user tables exist in addition to Root, Metadata,
+       // Confirm all 500 user tables exist in addition to Root, Metadata,
        // and ScanRef tables
  

Reply via email to